pub struct Formatted<'a> {
pub sign: &'static str,
pub parts: &'a [Part<'a>],
}🔬This is a nightly-only experimental API. (
numfmt)Expand description
Formatted result containing one or more parts. This can be written to the byte buffer or converted to the allocated string.
Fields
sign: &'static str🔬This is a nightly-only experimental API. (
numfmt)A byte slice representing a sign, either "", "-" or "+".
parts: &'a [Part<'a>]🔬This is a nightly-only experimental API. (
numfmt)Formatted parts to be rendered after a sign and optional zero padding.
Implementations
Sourceimpl<'a> Formatted<'a>
impl<'a> Formatted<'a>
Sourcepub fn len(&self) -> usize
🔬This is a nightly-only experimental API. (numfmt)
pub fn len(&self) -> usize
numfmt)Returns the byte length of combined formatted result.
Saturates at usize::MAX if the actual length is larger.
This matters on 16-bit targets, where exponential formatting can exceed
usize::MAX by emitting u16::MAX trailing zeroes plus "1." / "e0".
Sourcepub fn write(&self, out: &mut [u8]) -> Option<usize>
🔬This is a nightly-only experimental API. (numfmt)
pub fn write(&self, out: &mut [u8]) -> Option<usize>
numfmt)Writes all formatted parts into the supplied buffer.
Returns the number of written bytes, or None if the buffer is not enough.
(It may still leave partially written bytes in the buffer; do not rely on that.)